/// <reference types="react" />
import { NavigationScreenProp, NavigationState, NavigationRoute, NavigationParams, NavigationProp, NavigationDescriptor } from 'react-navigation';
import { StyleProp, ViewStyle, TextStyle } from 'react-native';
import Animated from 'react-native-reanimated';
export declare type Scene = {
    route: NavigationRoute;
    index: number;
    focused: boolean;
    tintColor?: string;
};
export declare type NavigationDrawerState = NavigationState & {
    isDrawerOpen: boolean;
};
export declare type NavigationDrawerProp<State = NavigationRoute, Params = NavigationParams> = NavigationScreenProp<State, Params> & {
    openDrawer: () => void;
    closeDrawer: () => void;
    toggleDrawer: () => void;
    jumpTo: (routeName: string, key?: string) => void;
};
export declare type NavigationDrawerOptions = {
    title?: string;
    drawerLabel?: React.ReactNode | ((props: {
        tintColor?: string;
        focused: boolean;
    }) => React.ReactNode);
    drawerIcon?: React.ReactNode | ((props: {
        tintColor?: string;
        focused: boolean;
    }) => React.ReactNode);
    drawerLockMode?: 'locked-closed' | 'locked-open';
};
export declare type NavigationDrawerConfig = {
    drawerWidth?: number | (() => number);
    contentComponent?: React.ComponentType<ContentComponentProps>;
    drawerPosition?: 'left' | 'right';
    drawerType?: 'front' | 'back' | 'slide';
    keyboardDismissMode?: 'none' | 'on-drag';
    swipeEdgeWidth?: number;
    swipeDistanceThreshold?: number;
    swipeVelocityThreshold?: number;
    hideStatusBar?: boolean;
    statusBarAnimation?: 'slide' | 'none' | 'fade';
    drawerBackgroundColor?: ThemedColor;
    overlayColor?: ThemedColor;
};
export declare type NavigationDrawerRouterConfig = {
    unmountInactiveRoutes?: boolean;
    resetOnBlur?: boolean;
    initialRouteName?: string;
    contentComponent?: React.ComponentType<ContentComponentProps>;
    contentOptions?: object;
};
export declare type ThemedColor = {
    light: string;
    dark: string;
};
export declare type DrawerNavigatorItemsProps = {
    items: NavigationRoute[];
    activeItemKey?: string | null;
    activeTintColor?: string | ThemedColor;
    activeBackgroundColor?: string | ThemedColor;
    inactiveTintColor?: string | ThemedColor;
    inactiveBackgroundColor?: string | ThemedColor;
    getLabel: (scene: Scene) => React.ReactNode;
    renderIcon: (scene: Scene) => React.ReactNode;
    onItemPress: (scene: {
        route: NavigationRoute;
        focused: boolean;
    }) => void;
    itemsContainerStyle?: StyleProp<ViewStyle>;
    itemStyle?: StyleProp<ViewStyle>;
    labelStyle?: StyleProp<TextStyle>;
    activeLabelStyle?: StyleProp<TextStyle>;
    inactiveLabelStyle?: StyleProp<TextStyle>;
    iconContainerStyle?: StyleProp<ViewStyle>;
    drawerPosition: 'left' | 'right';
};
export declare type ContentComponentProps = DrawerNavigatorItemsProps & {
    navigation: NavigationProp<NavigationDrawerState>;
    descriptors: {
        [key: string]: any;
    };
    drawerOpenProgress: Animated.Node<number>;
    screenProps: unknown;
};
export declare type SceneDescriptorMap = {
    [key: string]: NavigationDescriptor<NavigationParams, NavigationDrawerOptions, NavigationDrawerProp>;
};
